@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 from __future__ import print_function
 
-VERSION = '0.4.15'
+VERSION = '0.4.17'
 
 import os
 import sys
@@ -306,7 +306,11 @@ class Kernel(object):
     def patch(self, patch_script):
         os.chdir('{0}/sources/linux-{1}'.format(self.build_dir, self.version))
         self.log('Applying patch: {0}'.format(patch_script))
-        resp = subprocess.call([patch_script])
+        if self.verbose:
+            output = None
+        else:
+            output = subprocess.DEVNULL
+        resp = subprocess.call([patch_script], stdout=output, stderr=output)
         if resp != 0:
             raise EnvironmentError('Command failed: {0}'.format(patch_script))
 
@@ -384,13 +388,12 @@ class Kernel(object):
             stderr=subprocess.PIPE,
         )
         counter = 0
-        while True:
-            if make_process.poll() is not None:
-                break
-            line = make_process.stdout.readline()
-            if self_verbose and len(line):
+        while len(make_process.stdout.readline()):
+            if self.verbose:
                 counter += 1
-                progress_bar(counter, cap)
+                progress_bar(min(counter, cap), cap)
+            make_process.stdout.flush()
+        while make_process.poll() is None:
             time.sleep(1)
         if make_process.returncode != 0:
             print('Failed to make kernel')
